@@ -14,15 +14,16 @@ function(data,out)
   {
     return("Run 'jointplot' first! 'oplot' needs output of 'jointplot'!")
   }
+
+  ## Setting Values
+  nx<-dim(out[[1]])[2]
+  ny<-dim(out[[2]])[2]
   cols<-1:(nx+ny+1)
   if((nx+ny)>=7)
   {
     cols<-cols[-7]
   }
-  ## Setting Values
-  nx<-dim(out$Parameters)[2]
-  ny<-dim(out$Responses)[2]
-  numbW<-dim(out$Responses)[1]
+  numbW<-dim(out[[2]])[1]
   xdesign<-data[,1:nx]
   optmatrix<-out[[1]]
   reoptmatrix<-out[[2]]
@@ -38,14 +39,14 @@ function(data,out)
 
   # left plot
   par(fig=c(0,0.45,0.15,0.85),lwd=1,lty=6,bty="l",pty="s",las=1,cex=0.6,adj=0.5)
-  plot(xaxis1,optmatrix[,1],xlab="Weigth Matrices",ylim=c(min(xdesign),max(xdesign)+(max(xdesign)-min(xdesign))/4),ylab="",xaxt="n",yaxt="n")
+  plot(xaxis1,optmatrix[,1],xlab="Weigth Matrices",ylim=c(min(xdesign),max(xdesign)+(max(xdesign)-min(xdesign))/4),ylab="",xaxt="n",yaxt="n",pch=4)
   mtext("Parameter Setting",side=3,at=1,cex=0.6)
   axis(1,at=xaxis1,labels=xaxis1names)
   axis(2,at=yaxis1)
   lines(xaxis1,optmatrix[,1])
   for(i in 2:nx)
   {
-    points(xaxis1,optmatrix[,i],col=cols[i])
+    points(xaxis1,optmatrix[,i],col=cols[i],pch=4)
     lines(xaxis1,optmatrix[,i],col=cols[i])
   }
   legend(0.5,max(xdesign)+(max(xdesign)-min(xdesign))/4,names(data)[1:nx],col=cols[1:nx],bty="n",lwd=1)
@@ -62,14 +63,14 @@ function(data,out)
   # right Plot
 
   par(fig=c(0.5,0.95,0.15,0.85),new=TRUE,bty="l",pty="s",las=1)
-  plot(xaxis1,reoptplot[,1],xlab="Weight Matrices",ylab="",ylim=c(0,1.25+max(devstand)),xaxt="n",yaxt="n")
+  plot(xaxis1,reoptplot[,1],xlab="Weight Matrices",ylab="",ylim=c(0,1.25+max(devstand)),xaxt="n",yaxt="n",pch=4)
   mtext("Predicted Response",side=3,at=1,cex=0.6)
   axis(1,at=xaxis1,labels=xaxis1names)
   axis(2,at=c(0.25,0.625,1),labels=c("","",""))
   lines(xaxis1,reoptplot[,1],col=cols[nx+1])
   for(i in 2:ny)
   {
-    points(xaxis1,reoptplot[,i],col=cols[nx+i])
+    points(xaxis1,reoptplot[,i],col=cols[nx+i],pch=4)
     lines(xaxis1,reoptplot[,i],col=cols[nx+i])
   }
   for(i in 1:ny)
@@ -86,7 +87,7 @@ function(data,out)
     {
       point2[1]<-reoptplot[i,j]+devstand[i,j]
       point2[2]<-reoptplot[i,j]-devstand[i,j]
-      points(point1,point2,col=cols[nx+j])
+      points(point1,point2,col=cols[nx+j],pch=4)
       lines(point1,point2,col=cols[nx+j])
     }
   }
